hentry parsing tests

# hentry parsing tests ‐ change logs

The files in this directory where designed to test the parsing of hentry and its output to the newer JSON structure of micorformats 2.

Theses are backwards compatibility tests for the older version 1 microformats specification. Please do not use this as a reference for authoring microformats.

## Change log:

- Update text output to be textContent non-trimmed ‐ 29 May 2015 by Glenn Jones
- Removed duplicate from items[] in summarycontent test ‐ 23 May 2015 by Glenn Jones
- Broke old HTML format into small files to aid simpler testing ‐ 21 May 2015 by Glenn Jones
- Updated JSON examples so it always has the rel={} object as well as the items=[] array ‐ 21 November 2013 by Glenn Jones
- Updated encoding issue on e-* ‐ 19 September 2013 by Glenn Jones
- Copied from version 1 test suite ‐ 7 January 2013 by Glenn Jones

## Contributors:

- Glenn Jones